summaryrefslogtreecommitdiff
path: root/src/mesa/main/context.h
diff options
context:
space:
mode:
authorKristian Høgsberg <krh@bitplanet.net>2010-10-12 12:02:01 -0400
committerKristian Høgsberg <krh@bitplanet.net>2010-10-13 09:43:24 -0400
commit31aca27c08d6a385c595d34fe4ee06390bf5b0e8 (patch)
tree798b14d851b87df251206b0896a91e99b5ae0127 /src/mesa/main/context.h
parentd3491e775fb07f891463b2185d74bbad62f3ed24 (diff)
Drop GLframebuffer typedef and just use struct gl_framebuffer
Diffstat (limited to 'src/mesa/main/context.h')
-rw-r--r--src/mesa/main/context.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/mesa/main/context.h b/src/mesa/main/context.h
index 969c07e53c..d89ae36a5c 100644
--- a/src/mesa/main/context.h
+++ b/src/mesa/main/context.h
@@ -32,13 +32,13 @@
* - GLcontext: this contains the Mesa rendering state
* - struct gl_config: this describes the color buffer (RGB vs. ci), whether or not
* there's a depth buffer, stencil buffer, etc.
* - GLframebuffer: contains pointers to the depth buffer, stencil buffer,
* accum buffer and alpha buffers.
*
* These types should be encapsulated by corresponding device driver
* data types. See xmesa.h and xmesaP.h for an example.
*
* In OOP terms, GLcontext, struct gl_config, and GLframebuffer are base classes
* which the device driver must derive from.
*
* The following functions create and destroy these data types.
@@ -142,8 +142,8 @@ extern void
_mesa_check_init_viewport(GLcontext *ctx, GLuint width, GLuint height);
extern GLboolean
-_mesa_make_current( GLcontext *ctx, GLframebuffer *drawBuffer,
- GLframebuffer *readBuffer );
+_mesa_make_current( GLcontext *ctx, struct gl_framebuffer *drawBuffer,
+ struct gl_framebuffer *readBuffer );
extern GLboolean
_mesa_share_state(GLcontext *ctx, GLcontext *ctxToShare);
@@ -32,13 +32,13 @@
* - struct gl_config: this describes the color buffer (RGB vs. ci), whether or not
* there's a depth buffer, stencil buffer, etc.
- * - GLframebuffer: contains pointers to the depth buffer, stencil buffer,
+ * - struct gl_framebuffer: contains pointers to the depth buffer, stencil buffer,
* accum buffer and alpha buffers.
*
@@ -32,13 +32,13 @@
* data types. See xmesa.h and xmesaP.h for an example.
*
- * In OOP terms, GLcontext, struct gl_config, and GLframebuffer are base classes
+ * In OOP terms, GLcontext, struct gl_config, and struct gl_framebuffer are base classes
* which the device driver must derive from.
*